# IQS9150/IQS9151 Arduino Example Code

## Introduction

This Arduino example code demonstrates how to set up and use the IQS9150/IQS9151 Integrated Circuit (IC). The IQS9150/IQS9151 is a high resolution trackpad device capable of supporting up to 26x19 channels. This class provides an easy means of initializing and interacting with the IQS9150/IQS9151 device from an Arduino-based device.

This example code is specifically aimed at the IQS9150 Evaluation Kit (PCB number _AZP1364A1_) and the IQS9151 Evaluation Kit (PCB Number _AZP1383A2_).

The IQS9150 Evaluation Kit is set up by default, this can be changed by changing which header file gets included at the top of `IQS9150_9151.cpp`. By default `IQS9150_v1.2_AZP1364A1_20241004.h` will be included, this can be changed to `IQS9151_AZP1383A2_SV0.0.h` to select the default setup for the IQS9151 Evaluation Kit.

If this example code needs to be used on a different hardware setup than the evaluation kits mentioned above, the header file that is included with the `#define` settings at the start of `IQS9150_9151.cpp` needs to be replaced.

```c
/* Include Files */
#include "IQS9150_9151.h"
#include "IQS9150_v1.2_AZP1364A1_20241004.h" //IQS9150 Evaluation Kit. Replace this file if you are using a different hardware setup.
// #include "IQS9151_AZP1383A2_SV0.0.h" //IQS9151 Evaluation Kit. Replace this file if you are using a different hardware setup.
```

This h-file can be generated by the Azoteq IQS9150/IQS9151 GUI.

This example code is intended for an Arduino Compatible board that uses 3.3 V logic. If a 5V logic Arduino board is used, a logic-level translator will be required between the Arduino-based board and the IQS9150/IQS9151.

## Arduino Code Configuration

The behaviour and pin assignments of the Arduino code can be configured with the `#define` settings at the start of `iqs9150-9151-example-code.ino`.

Ensure that the SDA and SCL pins on the IQS9150/IQS9151 hardware are connected to the correct corresponding pins on the Arduino Compatible board.

Change the following pin assignments and parameters to suit your hardware:

```c
/*** Defines ***/
#define DEMO_IQS9150_9151_ADDR                      0x56
#define DEMO_IQS9150_9151_POWER_PIN                 4
#define DEMO_IQS9150_9151_MCLR_PIN                  7
```

* `DEMO_IQS9150_9151_ADDR` is the IQS9150/IQS9151 I2C Slave address. For more information, refer to the datasheet and application notes found on the [IQS9150 Product Page](https://www.azoteq.com/product/iqs9150/) or on the [IQS9151 Product Page](https://www.azoteq.com/product/iqs9151/).

* `DEMO_IQS9150_9151_POWER_PIN` can be used to power the IQS9150/IQS9151 directly from an Arduino GPIO. This parameter sets which pin to use. This is an optional setting and can be removed if the IQS9150/IQS9151 is powered from the VCC pin or an external power supply.

* `DEMO_IQS9150_9151_RDY_PIN` sets the pin assignment for the IQS9150/IQS9151 ready pin.

NOTE: Please note that powering an IQS device directly from a GPIO is
_generally_ not recommended. However, the `DEMO_IQS9150_9151_POWER_PIN` in this
example could be used as an enable input to a voltage regulator.

## Example Code Flow Diagram

<p align="center">
  <img src="docs/images/flow-diagram.svg" />
</p>

## Board Library Installation

To use a third-party Arduino based board the following example can be referenced. The board used in this example is the SparkFun Pro Micro. In order to use this board, the SparkFun Board Library must be installed
in the Arduino IDE.

Add the SparkFun Board Library by opening Preferences (*File* > *Preferences*),
and paste the following URL into the "Additional Board Manager URLs" text box.

```
https://raw.githubusercontent.com/sparkfun/Arduino_Boards/master/IDE_Board_Manager/package_sparkfun_index.json
```

![board_manager_link](docs/images/arduino-board-manager-link.png)

Click "OK".
Then open the Board Manager under **Tools** > **Board** > **Boards Manager...**.

![board_manager](docs/images/board-manager.png)

Search for "SparkFun", and install "SparkFun AVR Boards by SparkFun".

![board-manager-sparkfun](docs/images/board-manager-sparkfun.png)

You can now select the "SparkFun Pro Micro" in the Board selection menu.

![select-pro-micro](docs/images/select-pro-micro.png)

Also be sure to select the "3.3 V, 8 MHz" version under *Tools* > *Processor*.

![select-3v3](docs/images/select-3v3.png)

Source: [Pro Micro Hookup Guide](https://learn.sparkfun.com/tutorials/pro-micro--fio-v3-hookup-guide)

## Serial Communication and Interface

The example code provides verbose serial feedback to aid users in the demonstration of start-up and operational functions. A successful initialization process will show the following over serial:

![iqs9150_successful_serial_with_touch](docs/images/iqs9150_successful_serial_with_touch.png)

The default serial feedback will show:

* `Gestures Events` - Will display when a gesture event is detected.
* `Finger X and Y` - Will display the absolute X and Y coordinates of all fingers that are detected on the
trackpad.
